@@ -63,7 +63,8 @@ struct interface
 };
 
 char *Release = "chkrootkit package",
-     *Version = "@(#) ifpromisc 0.8 (2003/11/30)";
+     *Version = "@(#) ifpromisc 0.9 (2007/06/15)";
+//     *Version = "@(#) ifpromisc 0.8 (2003/11/30)";
 
 int skfd = -1;				/* AF_INET or AF_PACKET raw socket desc.	*/
 int q = 0;                              /* Quiet mode on or off				*/
@@ -166,7 +167,8 @@ static void walk_process(char *process)
 
     if ((dir = opendir(path)) == NULL)
     {
-        perror(path);
+	if (errno != ENOENT)
+           perror(path);
         return;
     }
 
